#
# spec file for package kicad-doc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor html%{nil}
%define sname kicad-doc

%if "%flavor" == ""
ExclusiveArch:  do_not_build
%endif

%if "%flavor" == "pdf"
%define pkg_suffix -pdf
%bcond_without pdf
# Disabled, fails to build, asciidoc+dblatex no longer supported by upstream
# E.g. https://gitlab.com/kicad/services/kicad-doc/-/issues/808
ExclusiveArch:  do_not_build
%endif

%if "%flavor" == "html"
%bcond_with pdf
%endif

Name:           kicad-doc%{?pkg_suffix}
Version:        8.0.5
Release:        1.0.2.1.sr20240901
Summary:        Documentation and tutorials for KiCad
License:        CC-BY-SA-3.0 AND GPL-3.0-or-later
Group:          Documentation/HTML
URL:            https://www.kicad.org
Source:         https://gitlab.com/kicad/services/%{sname}/-/archive/%{version}/%{sname}-%{version}.tar.bz2#/%{sname}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE kicad-doc-notimestamp.patch davejplater@gmail.com -- Remove time stamped footer from html pages.
Patch0:         kicad-doc-notimestamp.patch
BuildRequires:  asciidoc >= 8.6.9
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.18
BuildRequires:  libxslt-tools
BuildRequires:  po4a >= 0.45
BuildRequires:  source-highlight
BuildRequires:  perl(Unicode::LineBreak)
%if %{with pdf}
BuildRequires:  dblatex >= 0.3.4
BuildRequires:  texlive-babel-catalan
BuildRequires:  texlive-babel-dutch
BuildRequires:  texlive-babel-french
BuildRequires:  texlive-babel-german
BuildRequires:  texlive-babel-italian
BuildRequires:  texlive-babel-polish
BuildRequires:  texlive-babel-russian
BuildRequires:  texlive-babel-spanish
BuildRequires:  texlive-fandol
BuildRequires:  texlive-gnu-freefont
BuildRequires:  texlive-xetex
BuildRequires:  vlgothic-fonts
BuildRequires:  tex(8r.enc)
BuildRequires:  tex(bahasa.ldf)
BuildRequires:  tex(cmap.sty)
BuildRequires:  tex(eu1enc.def)
BuildRequires:  tex(fancybox.sty)
BuildRequires:  tex(japanese.ldf)
BuildRequires:  tex(mathptmx.sty)
BuildRequires:  tex(mathrsfs.sty)
BuildRequires:  tex(pcrr8t.tfm)
BuildRequires:  tex(phvb8t.tfm)
BuildRequires:  tex(psyr.tfm)
BuildRequires:  tex(ptmr8t.tfm)
BuildRequires:  tex(pzdr.tfm)
BuildRequires:  tex(upquote.sty)
BuildRequires:  tex(xeCJK.sty)
BuildRequires:  tex(xltxtra.sty)
# kicad-doc owns the directories
BuildRequires:  kicad-doc
%endif
BuildArch:      noarch
Recommends:     kicad = %{version}

%description
Kicad is an open source software for the creation of electronic
schematic diagrams and printed circuit board artwork.
This is the documentation package for KiCad. It contains documentation
and tutorials.

%package        ca
Summary:        Catalan documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:ca)
Requires:       %{name}-en = %{version}

%description    ca
This package contains Catalan documentation and tutorials for KiCad

%package        de
Summary:        German documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:de)
Requires:       %{name}-en = %{version}

%description    de
This package contains German documentation and tutorials for KiCad

%package        en
Summary:        English documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:en)
Requires:       kicad = %{version}
Requires:       kicad-doc = %{version}

%description    en
This package contains English documentation and tutorials for KiCad

%package        es
Summary:        Spanish documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:es)
Requires:       %{name}-en = %{version}

%description    es
This package contains Spanish documentation and tutorials for KiCad

%package        fr
Summary:        French documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:fr)
Requires:       %{name}-en = %{version}

%description    fr
This package contains French documentation and tutorials for KiCad

%package        id
Summary:        Indonesian documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:id)
Requires:       %{name}-en = %{version}

%description    id
This package contains Indonesian documentation and tutorials for KiCad

%package        it
Summary:        Italian documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:it)
Requires:       %{name}-en = %{version}

%description    it
This package contains Italian documentation and tutorials for KiCad

%package        ja
Summary:        Japanese documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:ja)
Requires:       %{name}-en = %{version}

%description    ja
This package contains Japanese documentation and tutorials for KiCad

%package        pl
Summary:        Polish documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:pl)
Requires:       %{name}-en = %{version}

%description    pl
This package contains Polish documentation and tutorials for KiCad

%package        ru
Summary:        Russian documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:ru)
Requires:       %{name}-en = %{version}

%description    ru
This package contains Russian documentation and tutorials for KiCad

%package        zh
Summary:        Chinese documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(%{name}:zh)
Requires:       %{name}-en = %{version}

%description    zh
This package contains Chinese documentation and tutorials for KiCad

%prep
%autosetup -p0 -n %{sname}-%{version}

# asciidoc errors out if the `[code]` style is used with an unknown language
# https://gitlab.com/kicad/services/kicad-doc/-/issues/851
find . -iname \*adoc -exec sed -i -e 's/\[code/\[source/' '{}' \;
# Fix incorrect column with specifiers
# https://gitlab.com/kicad/services/kicad-doc/-/issues/852
find . -iname \*adoc -exec sed -i -e '/\[.*cols=/ { :m s/\(cols=.*\)\([0-9]\)%/\1\2/g ; t m }' '{}' \;
# asciidoc interprets the '[--...]' on a new line as a style name
find . -iname cli.adoc -exec sed -i -e 's/^\[--/ \[--/' '{}' \;

# These files are actually GIFs, https://gitlab.com/kicad/services/kicad-doc/-/issues/822
mv src/gerbview/images/zh/gerbview_x2_attribute.{png,gif}
mv src/gerbview/images/zh/gerbview_x2_component.{png,gif}
mv src/gerbview/images/zh/gerbview_x2_net.{png,gif}

%if %{with pdf}
# Workaround for dblatex bug #117 - randomly selected warning symbol
cp /usr/share/dblatex/latex/graphics/warning.pdf CMakeSupport/
%endif

%build
# Supported output formats: html;pdf;epub;
%if %{with pdf}
# SOURCE_DATE_EPOCH affirmation variable used by TeX
export FORCE_SOURCE_DATE=1
# Do not build PL translations, bad interaction of po4a, asciidoc and xetex (gh#KiCad/kicad-doc#697)
# RU also fails, "Undefined control sequence \cyrchar."
%cmake -DKICAD_DOC_PATH=%{_docdir}/kicad/help -DADOC_TOOLCHAIN=asciidoc -DPDF_GENERATOR=dblatex -DBUILD_FORMATS='pdf;' -DLANGUAGES='ca;de;en;es;fr;id;it;ja;zh'
%else
%cmake -DKICAD_DOC_PATH=%{_docdir}/kicad/help -DADOC_TOOLCHAIN=asciidoc -DBUILD_FORMATS='html;'
%endif
%{make_jobs}

%install
%cmake_install

for lang in ca de en es fr id it ja pl ru zh ; do
    %fdupes %{buildroot}%{_docdir}/kicad/help/$lang
done

%if %{without pdf}
%files
%dir %{_docdir}/kicad/
%dir %{_docdir}/kicad/help/
%doc AUTHORS_README.adoc CHEATSHEET.adoc README.adoc
%license LICENSE.adoc
%endif

%files ca
%{_docdir}/kicad/help/ca/

%files de
%{_docdir}/kicad/help/de/

%files en
%{_docdir}/kicad/help/en/

%files es
%{_docdir}/kicad/help/es/

%files fr
%{_docdir}/kicad/help/fr/

%files id
%{_docdir}/kicad/help/id/

%files it
%{_docdir}/kicad/help/it/

%files ja
%{_docdir}/kicad/help/ja/

%if %{without pdf}
%files pl
%{_docdir}/kicad/help/pl/

%files ru
%{_docdir}/kicad/help/ru/
%endif

%files zh
%{_docdir}/kicad/help/zh/

%changelog
* Wed Sep 18 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.5:
  See https://www.kicad.org/blog/2024/09/KiCad-8.0.5-Release/ for details
* Mon Jul 29 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.4:
  See https://www.kicad.org/blog/2024/07/KiCad-8.0.4-Release/ for details
* Wed Jun 12 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.3:
  See https://www.kicad.org/blog/2024/06/KiCad-8.0.3-Release/ for details
* Mon May  6 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.2:
  See https://www.kicad.org/blog/2024/04/KiCad-8.0.2-Release/ for details
* Fri Mar 15 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.1:
  See https://www.kicad.org/blog/2024/03/KiCad-8.0.1-Release/ for details
* Sun Feb 25 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.0:
  See https://www.kicad.org/blog/2024/02/KiCad-8.0.0-Release/ for details
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Jan  1 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.10:
  See https://www.kicad.org/blog/2023/12/KiCad-7.0.10-Release/ for details
* Thu Dec  7 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.9:
  See https://www.kicad.org/blog/2023/11/KiCad-7.0.9-Release/ for details
- update to 7.0.8:
  See https://www.kicad.org/blog/2023/09/KiCad-7.0.8-Release/ for details
- Update asciidoc fixups/workarounds
* Mon Sep 11 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.7:
  See https://www.kicad.org/blog/2023/08/KiCad-7.0.7-Release/ for details.
* Mon Aug 14 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.6:
  See https://www.kicad.org/blog/2023/07/KiCad-7.0.6-Release/ for details.
* Sat Jun  3 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.5:
  See https://www.kicad.org/blog/2023/05/KiCad-7.0.5-Release/ for details.
* Tue Apr 25 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.2:
  See https://www.kicad.org/blog/2023/04/KiCad-7.0.2-Release/ for details.
* Sat Mar 11 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.1:
  See https://www.kicad.org/blog/2023/03/KiCad-7.0.1-Release/ for details.
* Tue Feb 14 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.0:
  See https://www.kicad.org/blog/2023/02/Version-7.0.0-Released/ for details.
- Disabled pdf generation, PDF generation using asciidoc+dblatex
  is no longer supported by upstream and fails to build.
* Thu Jan 26 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 6.0.11:
  See https://www.kicad.org/blog/2023/01/KiCad-6.0.11-Release/ for details.
* Sat Nov  5 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.9
  See https://www.kicad.org/blog/2022/10/KiCad-6.0.9-Release/ for details.
* Fri Oct 28 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.8
  See https://www.kicad.org/blog/2022/09/KiCad-6.0.8-Release/ for details.
* Sun Aug 28 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.7
  See https://www.kicad.org/blog/2022/07/KiCad-6.0.7-Release/ for details.
* Tue Jun 21 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.6
  See https://www.kicad.org/blog/2022/06/KiCad-6.0.6-Release/ for details.
* Fri May 13 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.5
  See https://www.kicad.org/blog/2022/05/KiCad-6.0.5-Release/ for details.
* Sat Mar 19 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.4
  See https://www.kicad.org/blog/2022/03/KiCad-6.0.4-Release/ for details.
* Fri Feb 11 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.2
  See https://www.kicad.org/blog/2022/02/KiCad-6.0.2-Release/ for details.
* Tue Jan 25 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.1
  See https://www.kicad.org/blog/2022/01/KiCad-6.0.1-Release/ for details.
* Sat Dec 25 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.0
  See https://www.kicad.org/blog/2021/12/KiCad-6.0.0-Release/ for details.
* Thu Nov 18 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.12
  See https://kicad.org/blog/2021/11/KiCad-5.1.12-Release/ for details.
* Sat Oct 30 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.11
  See https://kicad.org/blog/2021/11/KiCad-5.1.11-Release/ for details.
- Replace references to old domain (hijacked) with kicad.org
  https://www.kicad.org/blog/2021/10/Avoid-links-to-former-kicad-domain/
* Tue Apr 27 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.10
  See https://kicad.org/blog/2021/05/KiCad-5.1.10-Release/ for details.
* Wed Dec 30 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.9
  See https://kicad.org/blog/2020/12/KiCad-5.1.9-Release/ for details.
* Fri Nov  6 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.8
  See https://kicad.org/blog/2020/11/KiCad-5.1.8-Release/ for details.
* Mon Sep 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.7, no changelog provided
* Fri May 29 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.6
  * Various smaller changes to the manuals and its translations
- Adjust dependencies and language provides
* Mon Nov 18 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.5
  * Various smaller changes to the manuals and its translations
* Wed Aug  7 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.4
  * Various smaller changes to the manuals and its translations
* Thu Apr 25 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.2
  * Updates to chinese and italian translations
* Tue Apr 16 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.1
  * Various smaller changes and translation updates
* Tue Mar 12 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.0
  * Various smaller changes and translation updates
  * (Empty) nl translation package removed
- Build PDF and HTML documentation as _multibuild
  * Remove dblatex BuildRequires for HTML build
* Thu Dec  6 2018 davejplater@gmail.com
- Update to release 5.0.2 in line with kicad update.
* Sat Oct 13 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to bugfix release 5.0.1
  * Various smaller changes and translation updates
- Remove verbose-a2x-debug.patch, no longer needed
* Sat Sep 29 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Require kicad-doc-en from other translation subpackages
  to provide a fallback for incomplete translations.
* Sun Aug  5 2018 stefan.bruens@rwth-aachen.de
- Cleanup spec file:
  * Remove unused BuildRequires: git
  * Reduce BuildRequires:, use only required TeX packages instead of
    the collection metapackages
  * Remove commented out commands
  * Drop default %%defattr
  * Use %%_docdir instead of %%_datadir
- Make build reproducible:
  * Fix randomly selected Warning symbol image
  * Force SOURCE_DATE_EPOCH usage in TeX
- Disable PDF generation on old distributions only, which
  fail to build due to a XeTeX bug
- Fix zh subpackage:
  * set correct language in locale(kicad-doc:zh) Provides
  * include in fdupes run
* Sun Jul 22 2018 davejplater@gmail.com
- Update to version 5.0.0, rebase verbose-a2x-debug.patch.
- Is now dual GPL-3.0+ and CC-BY-SA-3.0 licensed
- Added Chinese documentation.
* Mon Sep  4 2017 davejplater@gmail.com
- Update to version 4.0.7
- Link requires to the same kicad version
* Thu Apr 13 2017 davejplater@gmail.com
- Removed time stamp from pages with kicad-doc-notimestamp.patch
* Thu Mar 23 2017 xxxxxmichl@googlemail.com
- update to version 4.0.6
- Enabled indonesian language
* Thu Jan 12 2017 davejplater@gmail.com
- Update to version 4.0.5
- Disabled problematic pdf builds, html is needed for kicad help.
- Enabled Japanese and 42.x Italian packages html builds ok.
* Mon Sep 12 2016 davejplater@gmail.com
- Update to version 4.0.4
- Added new packages for Catalan, Russian, Spanish and German.
- Added verbose-a2x-debug.patch for verbose a2x output.
* Mon Mar 21 2016 dmitry_r@opensuse.org
- Update to version 4.0.2
* Wed Dec  2 2015 dmitry_r@opensuse.org
- Update to version 4.0.0
* Fri Sep 25 2015 dmitry_r@opensuse.org
- Update to version 4.0.0~20150925
* Wed Jul 31 2013 dmitry_r@opensuse.org
- Update to version 20130728
* Tue Apr  9 2013 werner.ho@gmx.de
- update to version 20130409
* Fri Jan 25 2013 dmitry_r@opensuse.org
- Update to version 20130120
- Change license to SUSE-OldFSFDocLicense [bnc#796377]
* Fri Dec 28 2012 dmitry_r@opensuse.org
- spec file cleanup
* Fri May 27 2011 werner.ho@gmx.de
- new version 2011-04-29
* Tue Apr 13 2010 mhopf@novell.com
- Update to 2010-04-06-SVN2508
* Tue Dec 16 2008 werner.ho@gmx.de
- directory fix for openSUSE 11.1
* Sat Oct  4 2008 werner.ho@gmx.de
- new version 1.1
* Tue Mar 25 2008 werner.ho@gmx.de
- initial build of the kicad documentation package version 1.0
